@@ -48,6 +48,7 @@ pub mod openstack;
 pub mod package;
 pub mod perl;
 pub mod php;
+pub mod pulumi;
 pub mod purescript;
 pub mod python;
 pub mod red;
@@ -75,8 +76,8 @@ pub use starship_root::*;
 #[serde(default)]
 pub struct FullConfig<'a> {
     // Root config
-    pub format: &'a str,
-    pub right_format: &'a str,
+    pub format: String,
+    pub right_format: String,
     pub scan_timeout: u64,
     pub command_timeout: u64,
     pub add_newline: bool,
@@ -125,6 +126,7 @@ pub struct FullConfig<'a> {
     package: package::PackageConfig<'a>,
     perl: perl::PerlConfig<'a>,
     php: php::PhpConfig<'a>,
+    pulumi: pulumi::PulumiConfig<'a>,
     purescript: purescript::PureScriptConfig<'a>,
     python: python::PythonConfig<'a>,
     red: red::RedConfig<'a>,
@@ -150,8 +152,8 @@ pub struct FullConfig<'a> {
 impl<'a> Default for FullConfig<'a> {
     fn default() -> Self {
         Self {
-            format: "$all",
-            right_format: "",
+            format: "$all".to_string(),
+            right_format: "".to_string(),
             scan_timeout: 30,
             command_timeout: 500,
             add_newline: true,
@@ -200,6 +202,7 @@ impl<'a> Default for FullConfig<'a> {
             package: Default::default(),
             perl: Default::default(),
             php: Default::default(),
+            pulumi: Default::default(),
             purescript: Default::default(),
             python: Default::default(),
             red: Default::default(),
