@@ -16,13 +16,14 @@ pub struct ShellConfig<'a> {
     pub nu_indicator: &'a str,
     pub xonsh_indicator: &'a str,
     pub unknown_indicator: &'a str,
+    pub style: &'a str,
     pub disabled: bool,
 }
 
 impl<'a> Default for ShellConfig<'a> {
     fn default() -> Self {
         ShellConfig {
-            format: "$indicator ",
+            format: "[$indicator]($style) ",
             bash_indicator: "bsh",
             fish_indicator: "fsh",
             zsh_indicator: "zsh",
@@ -33,6 +34,7 @@ impl<'a> Default for ShellConfig<'a> {
             nu_indicator: "nu",
             xonsh_indicator: "xsh",
             unknown_indicator: "",
+            style: "white bold",
             disabled: true,
         }
     }
