@@ -1,4 +1,5 @@
-use crate::config::StarshipConfig;
+use crate::config::{RootModuleConfig, StarshipConfig};
+use crate::configs::StarshipRootConfig;
 use crate::module::Module;
 use crate::utils::{exec_cmd, CommandOutput};
 
@@ -15,6 +16,7 @@ use std::fs;
 use std::path::{Path, PathBuf};
 use std::string::String;
 use std::time::{Duration, Instant};
+use terminal_size::terminal_size;
 
 /// Context contains data or common methods that may be used by multiple modules.
 /// The data contained within Context will be relevant to this particular rendering
@@ -63,8 +65,8 @@ pub struct Context<'a> {
     #[cfg(feature = "battery")]
     pub battery_info_provider: &'a (dyn crate::modules::BatteryInfoProvider + Send + Sync),
 
-    /// Timeout for the execution of commands
-    cmd_timeout: Duration,
+    /// Starship root config
+    pub root_config: StarshipRootConfig,
 }
 
 impl<'a> Context<'a> {
@@ -113,10 +115,12 @@ impl<'a> Context<'a> {
             .map(|(a, b)| (*a, b.vals.first().cloned().unwrap().into_string().unwrap()))
             .collect();
 
-        // Pipestatus is an arguments list
         let pipestatus = arguments
             .values_of("pipestatus")
-            .map(|args| args.into_iter().map(String::from).collect());
+            .map(Context::get_and_flatten_pipestatus)
+            .flatten();
+
+        log::trace!("Received completed pipestatus of {:?}", pipestatus);
 
         // Canonicalize the current path to resolve symlinks, etc.
         // NOTE: On Windows this converts the path to extended-path syntax.
@@ -124,10 +128,19 @@ impl<'a> Context<'a> {
         let current_dir = current_dir.canonicalize().unwrap_or(current_dir);
         let logical_dir = logical_path;
 
-        let cmd_timeout = Duration::from_millis(config.get_root_config().command_timeout);
+        let root_config = config
+            .config
+            .as_ref()
+            .map_or_else(StarshipRootConfig::default, StarshipRootConfig::load);
 
         let right = arguments.is_present("right");
 
+        let width = arguments
+            .value_of("terminal_width")
+            .and_then(|w| w.parse().ok())
+            .or_else(|| terminal_size().map(|(w, _)| w.0 as usize))
+            .unwrap_or(80);
+
         Context {
             config,
             properties,
@@ -138,16 +151,14 @@ impl<'a> Context<'a> {
             repo: OnceCell::new(),
             shell,
             right,
-            width: term_size::dimensions()
-                .map(|(width, _)| width)
-                .unwrap_or_default(),
+            width,
             #[cfg(test)]
             env: HashMap::new(),
             #[cfg(test)]
             cmd: HashMap::new(),
             #[cfg(feature = "battery")]
             battery_info_provider: &crate::modules::BatteryInfoProviderImpl,
-            cmd_timeout,
+            root_config,
         }
     }
 
@@ -195,6 +206,26 @@ impl<'a> Context<'a> {
         dir
     }
 
+    /// Reads and appropriately flattens multiple args for pipestatus
+    pub fn get_and_flatten_pipestatus(args: clap::Values) -> Option<Vec<String>> {
+        // Due to shell differences, we can potentially receive individual or space
+        // separated inputs, e.g. "0","1","2","0" is the same as "0 1 2 0" and
+        // "0 1", "2 0". We need to accept all these formats and return a Vec<String>
+        let parsed_vals = args
+            .into_iter()
+            .map(|x| x.split_ascii_whitespace())
+            .flatten()
+            .map(|x| x.to_string())
+            .collect::<Vec<String>>();
+        // If the vector is zero-length, we should pretend that we didn't get a
+        // pipestatus at all (since this is the input `--pipestatus=""`)
+        if parsed_vals.is_empty() {
+            None
+        } else {
+            Some(parsed_vals)
+        }
+    }
+
     /// Create a new module
     pub fn new_module(&self, name: &str) -> Module {
         let config = self.config.get_module_config(name);
@@ -252,8 +283,8 @@ impl<'a> Context<'a> {
 
     pub fn dir_contents(&self) -> Result<&DirContents, std::io::Error> {
         self.dir_contents.get_or_try_init(|| {
-            let timeout = Duration::from_millis(self.config.get_root_config().scan_timeout);
-            DirContents::from_path_with_timeout(&self.current_dir, timeout)
+            let timeout = self.root_config.scan_timeout;
+            DirContents::from_path_with_timeout(&self.current_dir, Duration::from_millis(timeout))
         })
     }
 
@@ -291,7 +322,11 @@ impl<'a> Context<'a> {
                 return output.clone();
             }
         }
-        exec_cmd(&cmd, args, self.cmd_timeout)
+        exec_cmd(
+            &cmd,
+            args,
+            Duration::from_millis(self.root_config.command_timeout),
+        )
     }
 }
 
@@ -324,7 +359,8 @@ impl DirContents {
         fs::read_dir(base)?
             .enumerate()
             .take_while(|(n, _)| {
-                n & 0xFF != 0 // only check timeout once every 2^8 entries
+                cfg!(test) // ignore timeout during tests
+                || n & 0xFF != 0 // only check timeout once every 2^8 entries
                 || start.elapsed() < timeout
             })
             .filter_map(|(_, entry)| entry.ok())
