@@ -46,9 +46,12 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
         false => PipeStatusStatus::Disabled,
     };
 
+    // Exit code is zero and pipestatus is all zero or disabled/missing
     if exit_code == "0"
-        && (pipestatus_status == PipeStatusStatus::Disabled
-            || pipestatus_status == PipeStatusStatus::NoPipe)
+        && (match pipestatus_status {
+            PipeStatusStatus::Pipe(ps) => ps.iter().all(|s| s == "0"),
+            _ => true,
+        })
     {
         return None;
     }
@@ -58,7 +61,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
         PipeStatusStatus::Pipe(pipestatus) => pipestatus
             .iter()
             .map(
-                |ec| match format_exit_code(ec.as_str(), config.format, None, &config) {
+                |ec| match format_exit_code(ec.as_str(), config.format, None, &config, context) {
                     Ok(segments) => segments
                         .into_iter()
                         .map(|s| s.to_string())
@@ -76,7 +79,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
         PipeStatusStatus::Pipe(_) => config.pipestatus_format,
         _ => config.format,
     };
-    let parsed = format_exit_code(exit_code, main_format, Some(&pipestatus), &config);
+    let parsed = format_exit_code(exit_code, main_format, Some(&pipestatus), &config, context);
 
     module.set_segments(match parsed {
         Ok(segments) => segments,
@@ -93,6 +96,7 @@ fn format_exit_code<'a>(
     format: &'a str,
     pipestatus: Option<&str>,
     config: &'a StatusConfig,
+    context: &'a Context,
 ) -> Result<Vec<Segment>, StringFormatterError> {
     let exit_code_int: ExitCode = match exit_code.parse() {
         Ok(i) => i,
@@ -161,7 +165,7 @@ fn format_exit_code<'a>(
                 }
                 _ => None,
             })
-            .parse(None)
+            .parse(None, Some(context))
     })
 }
 
@@ -412,13 +416,13 @@ mod tests {
     #[test]
     fn pipeline_uses_pipestatus_format() {
         let exit_values = [
-            [0, 0, 0, 0],
+            [0, 1, 0, 0],
             [0, 1, 2, 3],
             [130, 126, 131, 127],
             [1, 1, 1, 1],
         ];
         let exit_values_rendered = [
-            "PSF 🟢=🟢 🟢 🟢",
+            "PSF 🟢=🔴 🟢 🟢",
             "PSF 🟢=🔴 🔴 🔴",
             "PSF 🧱=🚫 ⚡ 🔍",
             "PSF 🔴=🔴 🔴 🔴",
@@ -456,13 +460,13 @@ mod tests {
     #[test]
     fn pipeline_no_map_symbols() {
         let exit_values = [
-            [0, 0, 0, 0],
+            [0, 1, 0, 0],
             [0, 1, 2, 3],
             [130, 126, 131, 127],
             [1, 1, 1, 1],
         ];
         let exit_values_rendered = [
-            "PSF 🟢=🟢0 🟢0 🟢0",
+            "PSF 🟢=🔴1 🟢0 🟢0",
             "PSF 🟢=🔴1 🔴2 🔴3",
             "PSF INT🔴=🔴126 🔴1313 🔴127",
             "PSF 🔴=🔴1 🔴1 🔴1",
@@ -516,6 +520,26 @@ mod tests {
         assert_eq!(expected, actual);
     }
 
+    #[test]
+    fn successful_pipeline_pipestatus_enabled() {
+        let pipe_exit_code = [0, 0, 0];
+
+        let main_exit_code = 0;
+
+        let expected = None;
+
+        let actual = ModuleRenderer::new("status")
+            .config(toml::toml! {
+                [status]
+                disabled = false
+                pipestatus = true
+            })
+            .status(main_exit_code)
+            .pipestatus(&pipe_exit_code)
+            .collect();
+        assert_eq!(expected, actual);
+    }
+
     #[test]
     fn pipeline_disabled() {
         let exit_values = [[130, 126, 131, 127], [1, 1, 1, 1]];
